function x=sintetf(sp,w,t)
%x=sintetf(sp,w,t);
% sp: valores de la transformada
% w: frecuencias de los coeficientes
% t: puntos donde se quiere reconstruir la onda

nfreq=length(sp);
paso=w(2)-w(1);
npuntos=length(t);
im=sqrt(-1);

for i=1:npuntos
   integ=0;
   for j=1:nfreq
      integ=integ+sp(j)*exp(im*w(j)*t(i))*paso;
   end
   x(i)=integ/(2*pi);
end
